measuretools.extend_measures_in_expr_and_apply_full_measure_tuplets_to_measure_contents
=======================================================================================

.. autofunction:: abjad.tools.measuretools.extend_measures_in_expr_and_apply_full_measure_tuplets_to_measure_contents.extend_measures_in_expr_and_apply_full_measure_tuplets_to_measure_contents
